@@ -9,6 +9,7 @@
 ###########################################################################
 """`verdi code` command."""
 from functools import partial
+import logging
 
 import click
 import tabulate
@@ -192,16 +193,25 @@ def delete(codes, verbose, dry_run, force):
 
     Note that codes are part of the data provenance, and deleting a code will delete all calculations using it.
     """
-    from aiida.manage.database.delete.nodes import delete_nodes
+    from aiida.common.log import override_log_formatter_context
+    from aiida.tools import delete_nodes, DELETE_LOGGER
 
-    verbosity = 1
-    if force:
-        verbosity = 0
-    elif verbose:
-        verbosity = 2
+    verbosity = logging.DEBUG if verbose else logging.INFO
+    DELETE_LOGGER.setLevel(verbosity)
 
     node_pks_to_delete = [code.pk for code in codes]
-    delete_nodes(node_pks_to_delete, dry_run=dry_run, verbosity=verbosity, force=force)
+
+    def _dry_run_callback(pks):
+        if not pks or force:
+            return False
+        echo.echo_warning(f'YOU ARE ABOUT TO DELETE {len(pks)} NODES! THIS CANNOT BE UNDONE!')
+        return not click.confirm('Shall I continue?', abort=True)
+
+    with override_log_formatter_context('%(message)s'):
+        _, was_deleted = delete_nodes(node_pks_to_delete, dry_run=dry_run or _dry_run_callback)
+
+    if was_deleted:
+        echo.echo_success('Finished deletion.')
 
 
 @verdi_code.command()
