@@ -338,7 +338,7 @@ def computer_disable(computer, user):
 
 @verdi_computer.command('list')
 @options.ALL(help='Show also disabled or unconfigured computers.')
-@options.RAW(help='Show only the computer names, one per line.')
+@options.RAW(help='Show only the computer labels, one per line.')
 @with_dbenv()
 def computer_list(all_entries, raw):
     """List all available computers."""
@@ -346,7 +346,7 @@ def computer_list(all_entries, raw):
 
     if not raw:
         echo.echo_info('List of configured computers')
-        echo.echo_info("Use 'verdi computer show COMPUTERNAME' to display more detailed information")
+        echo.echo_info("Use 'verdi computer show COMPUTERLABEL' to display more detailed information")
 
     computers = Computer.objects.all()
     user = User.objects.get_default()
@@ -357,7 +357,7 @@ def computer_list(all_entries, raw):
     sort = lambda computer: computer.label
     highlight = lambda comp: comp.is_user_configured(user) and comp.is_user_enabled(user)
     hide = lambda comp: not (comp.is_user_configured(user) and comp.is_user_enabled(user)) and not all_entries
-    echo.echo_formatted_list(computers, ['name'], sort=sort, highlight=highlight, hide=hide)
+    echo.echo_formatted_list(computers, ['label'], sort=sort, highlight=highlight, hide=hide)
 
 
 @verdi_computer.command('show')
