@@ -35,10 +35,10 @@ def profile_list():
         # to be able to see the configuration directory, for instance for those who have set `AIIDA_PATH`. This way
         # they can at least verify that it is correctly set.
         from aiida.manage.configuration.settings import AIIDA_CONFIG_FOLDER
-        echo.echo_info('configuration folder: {}'.format(AIIDA_CONFIG_FOLDER))
+        echo.echo_info(f'configuration folder: {AIIDA_CONFIG_FOLDER}')
         echo.echo_critical(str(exception))
     else:
-        echo.echo_info('configuration folder: {}'.format(config.dirpath))
+        echo.echo_info(f'configuration folder: {config.dirpath}')
 
     if not config.profiles:
         echo.echo_warning('no profiles configured: run `verdi setup` to create one')
@@ -56,7 +56,7 @@ def profile_show(profile):
     if profile is None:
         echo.echo_critical('no profile to show')
 
-    echo.echo_info('Profile: {}'.format(profile.name))
+    echo.echo_info(f'Profile: {profile.name}')
     data = sorted([(k.lower(), v) for k, v in profile.dictionary.items()])
     echo.echo(tabulate.tabulate(data))
 
@@ -71,7 +71,7 @@ def profile_setdefault(profile):
         echo.echo_critical(str(exception))
 
     config.set_default_profile(profile.name, overwrite=True).store()
-    echo.echo_success('{} set as default profile'.format(profile.name))
+    echo.echo_success(f'{profile.name} set as default profile')
 
 
 @verdi_profile.command('delete')
@@ -103,7 +103,7 @@ def profile_delete(force, include_config, include_db, include_repository, profil
     from aiida.manage.configuration.setup import delete_profile
 
     for profile in profiles:
-        echo.echo_info("Deleting profile '{}'".format(profile.name))
+        echo.echo_info(f"Deleting profile '{profile.name}'")
         delete_profile(
             profile,
             non_interactive=force,
