@@ -13,21 +13,27 @@
 import importlib
 import logging
 import traceback
+from typing import Any, Hashable, Optional, TYPE_CHECKING
 
-import plumpy
+import plumpy.persistence
+import plumpy.loaders
+from plumpy.exceptions import PersistenceError
 
 from aiida.orm.utils import serialize
 
+if TYPE_CHECKING:
+    from aiida.engine.processes.process import Process
+
 __all__ = ('AiiDAPersister', 'ObjectLoader', 'get_object_loader')
 
 LOGGER = logging.getLogger(__name__)
 OBJECT_LOADER = None
 
 
-class ObjectLoader(plumpy.DefaultObjectLoader):
+class ObjectLoader(plumpy.loaders.DefaultObjectLoader):
     """Custom object loader for `aiida-core`."""
 
-    def load_object(self, identifier):
+    def load_object(self, identifier: str) -> Any:  # pylint: disable=no-self-use
         """Attempt to load the object identified by the given `identifier`.
 
         .. note:: We override the `plumpy.DefaultObjectLoader` to be able to throw an `ImportError` instead of a
@@ -37,11 +43,11 @@ class ObjectLoader(plumpy.DefaultObjectLoader):
         :return: loaded object
         :raises ImportError: if the object cannot be loaded
         """
-        module, name = identifier.split(':')
+        module_name, name = identifier.split(':')
         try:
-            module = importlib.import_module(module)
+            module = importlib.import_module(module_name)
         except ImportError:
-            raise ImportError(f"module '{module}' from identifier '{identifier}' could not be loaded")
+            raise ImportError(f"module '{module_name}' from identifier '{identifier}' could not be loaded")
 
         try:
             return getattr(module, name)
@@ -49,11 +55,11 @@ class ObjectLoader(plumpy.DefaultObjectLoader):
             raise ImportError(f"object '{name}' from identifier '{identifier}' could not be loaded")
 
 
-def get_object_loader():
+def get_object_loader() -> ObjectLoader:
     """Return the global AiiDA object loader.
 
     :return: The global object loader
-    :rtype: :class:`plumpy.ObjectLoader`
+
     """
     global OBJECT_LOADER
     if OBJECT_LOADER is None:
@@ -61,15 +67,15 @@ def get_object_loader():
     return OBJECT_LOADER
 
 
-class AiiDAPersister(plumpy.Persister):
+class AiiDAPersister(plumpy.persistence.Persister):
     """Persister to take saved process instance states and persisting them to the database."""
 
-    def save_checkpoint(self, process, tag=None):
+    def save_checkpoint(self, process: 'Process', tag: Optional[str] = None):  # type: ignore[override] # pylint: disable=no-self-use
         """Persist a Process instance.
 
         :param process: :class:`aiida.engine.Process`
         :param tag: optional checkpoint identifier to allow distinguishing multiple checkpoints for the same process
-        :raises: :class:`plumpy.PersistenceError` Raised if there was a problem saving the checkpoint
+        :raises: :class:`PersistenceError` Raised if there was a problem saving the checkpoint
         """
         LOGGER.debug('Persisting process<%d>', process.pid)
 
@@ -77,26 +83,26 @@ class AiiDAPersister(plumpy.Persister):
             raise NotImplementedError('Checkpoint tags not supported yet')
 
         try:
-            bundle = plumpy.Bundle(process, plumpy.LoadSaveContext(loader=get_object_loader()))
+            bundle = plumpy.persistence.Bundle(process, plumpy.persistence.LoadSaveContext(loader=get_object_loader()))
         except ImportError:
             # Couldn't create the bundle
-            raise plumpy.PersistenceError(f"Failed to create a bundle for '{process}': {traceback.format_exc()}")
+            raise PersistenceError(f"Failed to create a bundle for '{process}': {traceback.format_exc()}")
 
         try:
             process.node.set_checkpoint(serialize.serialize(bundle))
         except Exception:
-            raise plumpy.PersistenceError(f"Failed to store a checkpoint for '{process}': {traceback.format_exc()}")
+            raise PersistenceError(f"Failed to store a checkpoint for '{process}': {traceback.format_exc()}")
 
         return bundle
 
-    def load_checkpoint(self, pid, tag=None):
+    def load_checkpoint(self, pid: Hashable, tag: Optional[str] = None) -> plumpy.persistence.Bundle:  # pylint: disable=no-self-use
         """Load a process from a persisted checkpoint by its process id.
 
         :param pid: the process id of the :class:`plumpy.Process`
         :param tag: optional checkpoint identifier to allow retrieving a specific sub checkpoint
         :return: a bundle with the process state
         :rtype: :class:`plumpy.Bundle`
-        :raises: :class:`plumpy.PersistenceError` Raised if there was a problem loading the checkpoint
+        :raises: :class:`PersistenceError` Raised if there was a problem loading the checkpoint
         """
         from aiida.common.exceptions import MultipleObjectsError, NotExistent
         from aiida.orm import load_node
@@ -107,17 +113,17 @@ class AiiDAPersister(plumpy.Persister):
         try:
             calculation = load_node(pid)
         except (MultipleObjectsError, NotExistent):
-            raise plumpy.PersistenceError(f'Failed to load the node for process<{pid}>: {traceback.format_exc()}')
+            raise PersistenceError(f'Failed to load the node for process<{pid}>: {traceback.format_exc()}')
 
         checkpoint = calculation.checkpoint
 
         if checkpoint is None:
-            raise plumpy.PersistenceError(f'Calculation<{calculation.pk}> does not have a saved checkpoint')
+            raise PersistenceError(f'Calculation<{calculation.pk}> does not have a saved checkpoint')
 
         try:
             bundle = serialize.deserialize(checkpoint)
         except Exception:
-            raise plumpy.PersistenceError(f'Failed to load the checkpoint for process<{pid}>: {traceback.format_exc()}')
+            raise PersistenceError(f'Failed to load the checkpoint for process<{pid}>: {traceback.format_exc()}')
 
         return bundle
 
@@ -127,14 +133,14 @@ class AiiDAPersister(plumpy.Persister):
         :return: list of PersistedCheckpoint tuples with element containing the process id and optional checkpoint tag.
         """
 
-    def get_process_checkpoints(self, pid):
+    def get_process_checkpoints(self, pid: Hashable):
         """Return a list of all the current persisted process checkpoints for the specified process.
 
         :param pid: the process pid
         :return: list of PersistedCheckpoint tuples with element containing the process id and optional checkpoint tag.
         """
 
-    def delete_checkpoint(self, pid, tag=None):
+    def delete_checkpoint(self, pid: Hashable, tag: Optional[str] = None) -> None:  # pylint: disable=no-self-use,unused-argument
         """Delete a persisted process checkpoint, where no error will be raised if the checkpoint does not exist.
 
         :param pid: the process id of the :class:`plumpy.Process`
@@ -145,7 +151,7 @@ class AiiDAPersister(plumpy.Persister):
         calc = load_node(pid)
         calc.delete_checkpoint()
 
-    def delete_process_checkpoints(self, pid):
+    def delete_process_checkpoints(self, pid: Hashable):
         """Delete all persisted checkpoints related to the given process id.
 
         :param pid: the process id of the :class:`aiida.engine.processes.process.Process`
