@@ -8,17 +8,30 @@
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 """Module with `Node` sub class for calculation job processes."""
-
+import datetime
+from typing import Any, AnyStr, Dict, List, Optional, Sequence, Tuple, Type, Union
+from typing import TYPE_CHECKING
 import warnings
 
 from aiida.common import exceptions
 from aiida.common.datastructures import CalcJobState
 from aiida.common.lang import classproperty
 from aiida.common.links import LinkType
+from aiida.common.folders import Folder
 from aiida.common.warnings import AiidaDeprecationWarning
 
 from .calculation import CalculationNode
 
+if TYPE_CHECKING:
+    from aiida.engine.processes.builder import ProcessBuilder
+    from aiida.orm import FolderData
+    from aiida.orm.authinfos import AuthInfo
+    from aiida.orm.utils.calcjob import CalcJobResultManager
+    from aiida.parsers import Parser
+    from aiida.schedulers.datastructures import JobInfo, JobState
+    from aiida.tools.calculations import CalculationTools
+    from aiida.transports import Transport
+
 __all__ = ('CalcJobNode',)
 
 
@@ -45,7 +58,7 @@ class CalcJobNode(CalculationNode):
     _tools = None
 
     @property
-    def tools(self):
+    def tools(self) -> 'CalculationTools':
         """Return the calculation tools that are registered for the process type associated with this calculation.
 
         If the entry point name stored in the `process_type` of the CalcJobNode has an accompanying entry point in the
@@ -76,7 +89,7 @@ class CalcJobNode(CalculationNode):
         return self._tools
 
     @classproperty
-    def _updatable_attributes(cls):  # pylint: disable=no-self-argument
+    def _updatable_attributes(cls) -> Tuple[str, ...]:  # pylint: disable=no-self-argument
         return super()._updatable_attributes + (
             cls.CALC_JOB_STATE_KEY,
             cls.REMOTE_WORKDIR_KEY,
@@ -91,7 +104,7 @@ class CalcJobNode(CalculationNode):
         )
 
     @classproperty
-    def _hash_ignored_attributes(cls):  # pylint: disable=no-self-argument
+    def _hash_ignored_attributes(cls) -> Tuple[str, ...]:  # pylint: disable=no-self-argument
         return super()._hash_ignored_attributes + (
             'queue_name',
             'account',
@@ -101,7 +114,7 @@ class CalcJobNode(CalculationNode):
             'max_memory_kb',
         )
 
-    def _get_objects_to_hash(self):
+    def _get_objects_to_hash(self) -> List[Any]:
         """Return a list of objects which should be included in the hash.
 
         This method is purposefully overridden from the base `Node` class, because we do not want to include the
@@ -112,7 +125,7 @@ class CalcJobNode(CalculationNode):
         """
         from importlib import import_module
         objects = [
-            import_module(self.__module__.split('.', 1)[0]).__version__,
+            import_module(self.__module__.split('.', 1)[0]).__version__,  # type: ignore[attr-defined]
             {
                 key: val
                 for key, val in self.attributes_items()
@@ -127,7 +140,7 @@ class CalcJobNode(CalculationNode):
         ]
         return objects
 
-    def get_builder_restart(self):
+    def get_builder_restart(self) -> 'ProcessBuilder':
         """Return a `ProcessBuilder` that is ready to relaunch the same `CalcJob` that created this node.
 
         The process class will be set based on the `process_type` of this node and the inputs of the builder will be
@@ -137,15 +150,14 @@ class CalcJobNode(CalculationNode):
         In addition to prepopulating the input nodes, which is implemented by the base `ProcessNode` class, here we
         also add the `options` that were passed in the `metadata` input of the `CalcJob` process.
 
-        :return: `~aiida.engine.processes.builder.ProcessBuilder` instance
         """
         builder = super().get_builder_restart()
-        builder.metadata.options = self.get_options()
+        builder.metadata.options = self.get_options()  # type: ignore[attr-defined]
 
         return builder
 
     @property
-    def _raw_input_folder(self):
+    def _raw_input_folder(self) -> Folder:
         """
         Get the input folder object.
 
@@ -154,13 +166,15 @@ class CalcJobNode(CalculationNode):
         """
         from aiida.common.exceptions import NotExistent
 
+        assert self._repository is not None, 'repository not initialised'
+
         return_folder = self._repository._get_base_folder()  # pylint: disable=protected-access
         if return_folder.exists():
             return return_folder
 
         raise NotExistent('the `_raw_input_folder` has not yet been created')
 
-    def get_option(self, name):
+    def get_option(self, name: str) -> Optional[Any]:
         """
         Retun the value of an option that was set for this CalcJobNode
 
@@ -170,7 +184,7 @@ class CalcJobNode(CalculationNode):
         """
         return self.get_attribute(name, None)
 
-    def set_option(self, name, value):
+    def set_option(self, name: str, value: Any) -> None:
         """
         Set an option to the given value
 
@@ -181,21 +195,21 @@ class CalcJobNode(CalculationNode):
         """
         self.set_attribute(name, value)
 
-    def get_options(self):
+    def get_options(self) -> Dict[str, Any]:
         """
         Return the dictionary of options set for this CalcJobNode
 
         :return: dictionary of the options and their values
         """
         options = {}
-        for name in self.process_class.spec_options.keys():
+        for name in self.process_class.spec_options.keys():  # type: ignore[attr-defined]
             value = self.get_option(name)
             if value is not None:
                 options[name] = value
 
         return options
 
-    def set_options(self, options):
+    def set_options(self, options: Dict[str, Any]) -> None:
         """
         Set the options for this CalcJobNode
 
@@ -204,7 +218,7 @@ class CalcJobNode(CalculationNode):
         for name, value in options.items():
             self.set_option(name, value)
 
-    def get_state(self):
+    def get_state(self) -> Optional[CalcJobState]:
         """Return the calculation job active sub state.
 
         The calculation job state serves to give more granular state information to `CalcJobs`, in addition to the
@@ -223,10 +237,9 @@ class CalcJobNode(CalculationNode):
 
         return state
 
-    def set_state(self, state):
+    def set_state(self, state: CalcJobState) -> None:
         """Set the calculation active job state.
 
-        :param state: a string with the state from ``aiida.common.datastructures.CalcJobState``.
         :raise: ValueError if state is invalid
         """
         if not isinstance(state, CalcJobState):
@@ -234,21 +247,21 @@ class CalcJobNode(CalculationNode):
 
         self.set_attribute(self.CALC_JOB_STATE_KEY, state.value)
 
-    def delete_state(self):
+    def delete_state(self) -> None:
         """Delete the calculation job state attribute if it exists."""
         try:
             self.delete_attribute(self.CALC_JOB_STATE_KEY)
         except AttributeError:
             pass
 
-    def set_remote_workdir(self, remote_workdir):
+    def set_remote_workdir(self, remote_workdir: str) -> None:
         """Set the absolute path to the working directory on the remote computer where the calculation is run.
 
         :param remote_workdir: absolute filepath to the remote working directory
         """
         self.set_attribute(self.REMOTE_WORKDIR_KEY, remote_workdir)
 
-    def get_remote_workdir(self):
+    def get_remote_workdir(self) -> Optional[str]:
         """Return the path to the remote (on cluster) scratch folder of the calculation.
 
         :return: a string with the remote path
@@ -256,10 +269,10 @@ class CalcJobNode(CalculationNode):
         return self.get_attribute(self.REMOTE_WORKDIR_KEY, None)
 
     @staticmethod
-    def _validate_retrieval_directive(directives):
+    def _validate_retrieval_directive(directives: Sequence[Union[str, Tuple[str, str, str]]]) -> None:
         """Validate a list or tuple of file retrieval directives.
 
-        :param directives: a list or tuple of file retrieveal directives
+        :param directives: a list or tuple of file retrieval directives
         :raise ValueError: if the format of the directives is invalid
         """
         if not isinstance(directives, (tuple, list)):
@@ -284,7 +297,7 @@ class CalcJobNode(CalculationNode):
             if not isinstance(directive[2], int):
                 raise ValueError('invalid directive, three element has to be an integer representing the depth')
 
-    def set_retrieve_list(self, retrieve_list):
+    def set_retrieve_list(self, retrieve_list: Sequence[Union[str, Tuple[str, str, str]]]) -> None:
         """Set the retrieve list.
 
         This list of directives will instruct the daemon what files to retrieve after the calculation has completed.
@@ -295,14 +308,14 @@ class CalcJobNode(CalculationNode):
         self._validate_retrieval_directive(retrieve_list)
         self.set_attribute(self.RETRIEVE_LIST_KEY, retrieve_list)
 
-    def get_retrieve_list(self):
+    def get_retrieve_list(self) -> Optional[Sequence[Union[str, Tuple[str, str, str]]]]:
         """Return the list of files/directories to be retrieved on the cluster after the calculation has completed.
 
         :return: a list of file directives
         """
         return self.get_attribute(self.RETRIEVE_LIST_KEY, None)
 
-    def set_retrieve_temporary_list(self, retrieve_temporary_list):
+    def set_retrieve_temporary_list(self, retrieve_temporary_list: Sequence[Union[str, Tuple[str, str, str]]]) -> None:
         """Set the retrieve temporary list.
 
         The retrieve temporary list stores files that are retrieved after completion and made available during parsing
@@ -313,7 +326,7 @@ class CalcJobNode(CalculationNode):
         self._validate_retrieval_directive(retrieve_temporary_list)
         self.set_attribute(self.RETRIEVE_TEMPORARY_LIST_KEY, retrieve_temporary_list)
 
-    def get_retrieve_temporary_list(self):
+    def get_retrieve_temporary_list(self) -> Optional[Sequence[Union[str, Tuple[str, str, str]]]]:
         """Return list of files to be retrieved from the cluster which will be available during parsing.
 
         :return: a list of file directives
@@ -360,7 +373,7 @@ class CalcJobNode(CalculationNode):
         """
         return self.get_attribute(self.RETRIEVE_SINGLE_FILE_LIST_KEY, None)
 
-    def set_job_id(self, job_id):
+    def set_job_id(self, job_id: Union[int, str]) -> None:
         """Set the job id that was assigned to the calculation by the scheduler.
 
         .. note:: the id will always be stored as a string
@@ -369,14 +382,14 @@ class CalcJobNode(CalculationNode):
         """
         return self.set_attribute(self.SCHEDULER_JOB_ID_KEY, str(job_id))
 
-    def get_job_id(self):
+    def get_job_id(self) -> Optional[str]:
         """Return job id that was assigned to the calculation by the scheduler.
 
         :return: the string representation of the scheduler job id
         """
         return self.get_attribute(self.SCHEDULER_JOB_ID_KEY, None)
 
-    def set_scheduler_state(self, state):
+    def set_scheduler_state(self, state: 'JobState') -> None:
         """Set the scheduler state.
 
         :param state: an instance of `JobState`
@@ -390,7 +403,7 @@ class CalcJobNode(CalculationNode):
         self.set_attribute(self.SCHEDULER_STATE_KEY, state.value)
         self.set_attribute(self.SCHEDULER_LAST_CHECK_TIME_KEY, timezone.datetime_to_isoformat(timezone.now()))
 
-    def get_scheduler_state(self):
+    def get_scheduler_state(self) -> Optional['JobState']:
         """Return the status of the calculation according to the cluster scheduler.
 
         :return: a JobState enum instance.
@@ -404,7 +417,7 @@ class CalcJobNode(CalculationNode):
 
         return JobState(state)
 
-    def get_scheduler_lastchecktime(self):
+    def get_scheduler_lastchecktime(self) -> Optional[datetime.datetime]:
         """Return the time of the last update of the scheduler state by the daemon or None if it was never set.
 
         :return: a datetime object or None
@@ -417,30 +430,38 @@ class CalcJobNode(CalculationNode):
 
         return value
 
-    def set_detailed_job_info(self, detailed_job_info):
+    def set_detailed_job_info(self, detailed_job_info: Optional[dict]) -> None:
         """Set the detailed job info dictionary.
 
         :param detailed_job_info: a dictionary with metadata with the accounting of a completed job
         """
         self.set_attribute(self.SCHEDULER_DETAILED_JOB_INFO_KEY, detailed_job_info)
 
-    def get_detailed_job_info(self):
+    def get_detailed_job_info(self) -> Optional[dict]:
         """Return the detailed job info dictionary.
 
+        The scheduler is polled for the detailed job info after the job is completed and ready to be retrieved.
+
         :return: the dictionary with detailed job info if defined or None
         """
         return self.get_attribute(self.SCHEDULER_DETAILED_JOB_INFO_KEY, None)
 
-    def set_last_job_info(self, last_job_info):
+    def set_last_job_info(self, last_job_info: 'JobInfo') -> None:
         """Set the last job info.
 
         :param last_job_info: a `JobInfo` object
         """
         self.set_attribute(self.SCHEDULER_LAST_JOB_INFO_KEY, last_job_info.get_dict())
 
-    def get_last_job_info(self):
+    def get_last_job_info(self) -> Optional['JobInfo']:
         """Return the last information asked to the scheduler about the status of the job.
 
+        The last job info is updated on every poll of the scheduler, except for the final poll when the job drops from
+        the scheduler's job queue.
+        For completed jobs, the last job info therefore contains the "second-to-last" job info that still shows the job
+        as running. Please use :meth:`~aiida.orm.nodes.process.calculation.calcjob.CalcJobNode.get_detailed_job_info`
+        instead.
+
         :return: a `JobInfo` object (that closely resembles a dictionary) or None.
         """
         from aiida.schedulers.datastructures import JobInfo
@@ -454,28 +475,26 @@ class CalcJobNode(CalculationNode):
 
         return job_info
 
-    def get_authinfo(self):
+    def get_authinfo(self) -> 'AuthInfo':
         """Return the `AuthInfo` that is configured for the `Computer` set for this node.
 
         :return: `AuthInfo`
         """
-        from aiida.orm.authinfos import AuthInfo
-
         computer = self.computer
 
         if computer is None:
             raise exceptions.NotExistent('No computer has been set for this calculation')
 
-        return AuthInfo.from_backend_entity(self.backend.authinfos.get(computer=computer, user=self.user))
+        return computer.get_authinfo(self.user)
 
-    def get_transport(self):
+    def get_transport(self) -> 'Transport':
         """Return the transport for this calculation.
 
         :return: `Transport` configured with the `AuthInfo` associated to the computer of this node
         """
         return self.get_authinfo().get_transport()
 
-    def get_parser_class(self):
+    def get_parser_class(self) -> Optional[Type['Parser']]:
         """Return the output parser object for this calculation or None if no parser is set.
 
         :return: a `Parser` class.
@@ -491,11 +510,11 @@ class CalcJobNode(CalculationNode):
         return None
 
     @property
-    def link_label_retrieved(self):
+    def link_label_retrieved(self) -> str:
         """Return the link label used for the retrieved FolderData node."""
         return 'retrieved'
 
-    def get_retrieved_node(self):
+    def get_retrieved_node(self) -> Optional['FolderData']:
         """Return the retrieved data folder.
 
         :return: the retrieved FolderData node or None if not found
@@ -507,7 +526,7 @@ class CalcJobNode(CalculationNode):
             return None
 
     @property
-    def res(self):
+    def res(self) -> 'CalcJobResultManager':
         """
         To be used to get direct access to the parsed parameters.
 
@@ -520,7 +539,7 @@ class CalcJobNode(CalculationNode):
         from aiida.orm.utils.calcjob import CalcJobResultManager
         return CalcJobResultManager(self)
 
-    def get_scheduler_stdout(self):
+    def get_scheduler_stdout(self) -> Optional[AnyStr]:
         """Return the scheduler stderr output if the calculation has finished and been retrieved, None otherwise.
 
         :return: scheduler stderr output or None
@@ -538,7 +557,7 @@ class CalcJobNode(CalculationNode):
 
         return stdout
 
-    def get_scheduler_stderr(self):
+    def get_scheduler_stderr(self) -> Optional[AnyStr]:
         """Return the scheduler stdout output if the calculation has finished and been retrieved, None otherwise.
 
         :return: scheduler stdout output or None
@@ -556,6 +575,9 @@ class CalcJobNode(CalculationNode):
 
         return stderr
 
-    def get_description(self):
-        """Return a string with a description of the node based on its properties."""
-        return self.get_state()
+    def get_description(self) -> str:
+        """Return a description of the node based on its properties."""
+        state = self.get_state()
+        if not state:
+            return ''
+        return state.value
