@@ -8,19 +8,23 @@
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 """Module with `Node` sub class for workflow function processes."""
+from typing import TYPE_CHECKING
 
 from aiida.common.links import LinkType
 from aiida.orm.utils.mixins import FunctionCalculationMixin
 
 from .workflow import WorkflowNode
 
+if TYPE_CHECKING:
+    from aiida.orm import Node
+
 __all__ = ('WorkFunctionNode',)
 
 
 class WorkFunctionNode(FunctionCalculationMixin, WorkflowNode):
     """ORM class for all nodes representing the execution of a workfunction."""
 
-    def validate_outgoing(self, target, link_type, link_label):
+    def validate_outgoing(self, target: 'Node', link_type: LinkType, link_label: str) -> None:
         """
         Validate adding a link of the given type from ourself to a given node.
 
